@@ -145,14 +145,16 @@
       SUBROUTINE FVRINI(N,IT,T)
 
       IMPLICIT REAL*8(A-H,O-Z)
-!      PARAMETER(PI=3.1415926535897932385D0)
       DIMENSION T(2,0:N/4-1,2),IT(N/2) 
       REAL*16 PI
       PI=4*ATAN(1Q0)
 
 
       IF(N.LT.2) THEN
-        print *,'error: N.NE.2**P'
+        print *,'fvpack error: N.NE.2**P'
+        STOP
+      ELSE IF(MOD(N,2).NE.0) THEN
+        print *,'fvpack error: N.NE.2**P'
         STOP
       ELSE IF(N.EQ.2) THEN
         RETURN
