@@ -325,7 +325,6 @@
       SUBROUTINE FVZINI(N,IT,T)
 
       IMPLICIT REAL*8(A-H,O-Z)
-!      PARAMETER(PI=3.1415926535897932385D0)
       DIMENSION T(2,0:N/2-1),IT(2,0:N/2-1) 
       REAL*16 PI
 !     IT(1,0) ˤϥơ֥θĿȤ
@@ -333,7 +332,17 @@
       PI=4*ATAN(1Q0)
 
       IF(N.LT.2) THEN
-        print *,'error: N.NE.2**P'
+        print *,'fvpack error: N.NE.2**P'
+        STOP
+      END IF
+
+      JS=N
+      DO WHILE(MOD(JS,4).EQ.0)
+        JS=JS/4
+      END DO
+      
+      IF(JS.GE.3) THEN
+        print *,'fvpack error: N.NE.2**P'
         STOP
       END IF
 
@@ -360,17 +369,9 @@
 
       IT(1,0)=L
 
-      J=N
-      DO WHILE(MOD(J,4).EQ.0)
-        J=J/4
-      END DO
-      
-      IF(N.LE.1.OR.J.GE.3) THEN
-        print *,'error: N.NE.2**P'
-        STOP
-      ELSE IF(J.EQ.1) THEN
+      IF(JS.EQ.1) THEN
         IT(2,0)=0 ! N=4**P
-      ELSE IF(J.EQ.2) THEN
+      ELSE IF(JS.EQ.2) THEN
         IT(2,0)=1 ! N=4**P*2
       END IF
 
